<?php

namespace Litecms\MasterCryptoCurrency\Providers;

use Illuminate\Support\ServiceProvider;

class MasterCryptoCurrencyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'master_crypto_currency');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'master_crypto_currency');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.master_crypto_currency', function ($app) {
            return $this->app->make('Litecms\MasterCryptoCurrency\MasterCryptoCurrency');
        });

                // Bind MasterCurrency to repository
        $this->app->bind(
            'Litecms\MasterCryptoCurrency\Interfaces\MasterCurrencyRepositoryInterface',
            \Litecms\MasterCryptoCurrency\Repositories\Eloquent\MasterCurrencyRepository::class
        );

        $this->app->register(\Litecms\MasterCryptoCurrency\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\MasterCryptoCurrency\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\MasterCryptoCurrency\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.master_crypto_currency'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/master_crypto_currency.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/master_crypto_currency')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/master_crypto_currency')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
